@@ -1,5 +1,5 @@
 import click
-from indico_install.utils import run_cmd
+from indico_install.utils import run_cmd, find_names
 
 
 @click.command("restart")
@@ -63,15 +63,7 @@ def restart(ctx, services, all_services=False, contains=True, wait="0"):
                 )
         else:
             service_str = r"\|".join(services)
-            if not contains:
-                service_str = f"^{service_str}$"
-            _services = run_cmd(
-                (
-                    f"kubectl get {svc_type} --no-headers -o "
-                    f"custom-columns=NAME:.metadata.name | grep '{service_str}'"
-                ),
-                silent=True,
-            ).splitlines()
+            _services = find_names(svc_type, service_str, contains)
             for svc_to_update in _services:
                 svc_to_update = f"{svc_type}/{svc_to_update}"
                 run_cmd(
